:py:mod:`holisticai.datasets`
=============================

.. automodule:: holisticai.datasets
    :no-members:
    :no-inherited-members:

**Dataset Objects**

.. autosummary::
    :nosignatures:
    :template: class.rst
    :toctree: .generated/
    
    Dataset
    DatasetDict
    GroupByDataset
    DataLoader

**Dataset Loading Functions**

.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/

    load_dataset

**Raw Datasets**

.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/

    load_adult
    load_last_fm
    load_law_school
    load_student
    load_us_crime